From 0be8aa013e4ed94bcab88527887e85130816d256 Mon Sep 17 00:00:00 2001
From: Tomoya Fujita <Tomoya.Fujita@sony.com>
Date: Mon, 14 Oct 2024 12:24:42 -0700
Subject: [PATCH] rmw_fastrtps supports service event gid uniqueness test.
 (#2638)

Signed-off-by: Tomoya Fujita <Tomoya.Fujita@sony.com>
---
 rclcpp/test/rclcpp/test_service_introspection.cpp | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/rclcpp/test/rclcpp/test_service_introspection.cpp b/rclcpp/test/rclcpp/test_service_introspection.cpp
index ba9d80e1f7..af60eec281 100644
--- a/rclcpp/test/rclcpp/test_service_introspection.cpp
+++ b/rclcpp/test/rclcpp/test_service_introspection.cpp
@@ -124,10 +124,10 @@ TEST_F(TestServiceIntrospection, service_introspection_nominal)
   ASSERT_THAT(
     client_gid_arr,
     testing::Eq(event_map[ServiceEventInfo::REQUEST_SENT]->info.client_gid));
   // TODO(@fujitatomoya): Remove this if statement once other rmw implementations support test.
   // Only rmw_connextdds can pass this test requirement for now.
   // See more details for https://github.com/ros2/rmw/issues/357
-  if (std::string(rmw_get_implementation_identifier()).find("rmw_connextdds") == 0) {
+  if (std::string(rmw_get_implementation_identifier()).find("rmw_cyclonedds_cpp") != 0) {
     ASSERT_THAT(
       client_gid_arr,
       testing::Eq(event_map[ServiceEventInfo::REQUEST_RECEIVED]->info.client_gid));
@@ -124,10 +124,10 @@ TEST_F(TestServiceIntrospection, service_introspection_nominal)
     client_gid_arr,
     testing::Eq(event_map[ServiceEventInfo::REQUEST_SENT]->info.client_gid));
-  // TODO(@fujitatomoya): Remove this if statement once other rmw implementations support test.
-  // Only rmw_connextdds can pass this test requirement for now.
+  // TODO(@fujitatomoya): Remove this if statement once rmw implementations support test.
+  // rmw_cyclonedds_cpp does not pass this test requirement for now.
   // See more details for https://github.com/ros2/rmw/issues/357